/* institution portlet */
.portletDepartment .portletHeader,
.portletInstitution .portletHeader {
    text-align: center;
    padding-bottom: 0.5em;
}

.portletDepartment .line ,
.portletDepartment .portletHeader a ,
.portletInstitution .line ,
.portletInstitution .portletHeader a {
    display: block;
}

.portletDepartment .portletHeader img ,
.portletInstitution .portletHeader img {
    display: block;
    margin: 0 auto;
    padding: 0;
    padding-top: 1em;
}
/*
.portletInstitution .i_address {
    padding-bottom: 0.5em;
}
*/
.portletDepartment strong ,
.portletInstitution strong {
   background-color: &dtml-globalBackgroundColor;;
   display: block;
}
.portletDepartment img.portlet_label ,
.portletInstitution img.portlet_label {
    float: left;
}
.portletDepartment .portlet_content ,
.portletInstitution .portlet_content {
    display: block;
    margin-left: 20px;
    display: block;
    margin-top: 0.2em;
    margin-bottom: 0.2em;
}

/* portlets allgemein */
.portletItem {
    padding: 0em 1em;
}

