# -*- coding: utf-8 -*-

################################################################
# vs.org (C) 2011, Veit Schiele
################################################################

# $Id: config.py 2981 2011-03-16 10:54:12Z carsten $

"""
Common configuration constants
"""

PROJECTNAME = 'vs.org'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'Employee': 'vs.org: Add Employee',
    'Employeefolder': 'vs.org: Add Employeefolder',
    'Department': 'vs.org: Add Department',
    'Institution': 'vs.org: Add Institution',
}

DEPARTMENTS_PORTLET_COLUMN = u"plone.rightcolumn"

